pub enum AccessDecider {
Automatic,
Human(AccessApprover),
}Expand description
Who made a decision on an access request.
Variants
Automatic
The decision was made automatically by the governing access rule; no human approval was required.
Human(AccessApprover)
The decision was made by a human approver, whose identity is denormalized by the server.