pub enum AccessRuleError {
Validation(AccessRuleValidationError),
InvalidConditions(String),
MissingField(MissingFieldError),
Chrono(ParseError),
Api(ApiError),
}Expand description
Errors returned from super::AccessRulesClient operations.
Variants
Validation(AccessRuleValidationError)
The request failed local validation before being sent to the server.
InvalidConditions(String)
The conditions field of a server response could not be interpreted.
MissingField(MissingFieldError)
The server response was missing a field required to build the requested type.
Chrono(ParseError)
A date field in the server response could not be parsed.
Api(ApiError)
A network or (de)serialization error occurred while calling the server.